All of lore.kernel.org
 help / color / mirror / Atom feed
* [Fuego] Functional.raspi_kinstall
@ 2021-03-17 11:50 Pavan Arun Deshpande
  0 siblings, 0 replies; only message in thread
From: Pavan Arun Deshpande @ 2021-03-17 11:50 UTC (permalink / raw)
  To: Bird, Tim, tbird20d; +Cc: fuego


[-- Attachment #1.1: Type: text/plain, Size: 1159 bytes --]

Hi Tim,

Currently, we are using u-boot to support multiple kernel images. As part
of this migration, we moved to 64bit kernel and currently using 64bit ARM
images for RPI board.
So we have made some local changes to the scripts in
Functional.raspi_kinstall directory  to get it working with a 64-bit kernel
image.

Please find a diff patch of Functional.raspi_kinstall attached below.

Thanks and regards
Pavan Arun Deshpande

-- 






This
message contains confidential information and is intended only 
for the
individual(s) named. If you are not the intended
recipient, you are 
notified that disclosing, copying, distributing or taking any
action in 
reliance on the contents of this mail and attached file/s is strictly
prohibited. Please notify the
sender immediately and delete this e-mail 
from your system. E-mail transmission
cannot be guaranteed to be secured or 
error-free as information could be
intercepted, corrupted, lost, destroyed, 
arrive late or incomplete, or contain
viruses. The sender therefore does 
not accept liability for any errors or
omissions in the contents of this 
message, which arise as a result of e-mail
transmission.

[-- Attachment #1.2: Type: text/html, Size: 1390 bytes --]

[-- Attachment #2: raspi_kinstall.patch --]
[-- Type: text/x-patch, Size: 4625 bytes --]

diff --git a/tests/Functional.raspi_kinstall/fuego_test.sh b/tests/Functional.raspi_kinstall/fuego_test.sh
index 9a592fd..9c1368a 100755
--- a/tests/Functional.raspi_kinstall/fuego_test.sh
+++ b/tests/Functional.raspi_kinstall/fuego_test.sh
@@ -20,11 +20,11 @@ function test_build {
 
 function test_deploy {
     # put kernel on target in /tmp
-    put arch/arm/boot/zImage /tmp/kernel7.img
+    put arch/arm64/boot/Image /tmp/kernel8.img
     put modules.tgz /tmp
 
     # extract into /boot and /
-    cmd "cp /tmp/kernel7.img /boot/"
+    cmd "cp /tmp/kernel8.img /boot/"
     cmd "cd /; tar -xzf /tmp/modules.tgz"
     cmd "sync;sync;sync"
     target_reboot
diff --git a/tests/Functional.raspi_kinstall/rpi_code_checkout_build.sh b/tests/Functional.raspi_kinstall/rpi_code_checkout_build.sh
index f5f451b..704fbcf 100755
--- a/tests/Functional.raspi_kinstall/rpi_code_checkout_build.sh
+++ b/tests/Functional.raspi_kinstall/rpi_code_checkout_build.sh
@@ -1,60 +1,60 @@
 # assume we start in top directory of kernel source tree
 
 # old code for pipeline build
-#cd ${JENKINS_HOME}/jobs/pipeline/BUILD_${JOB_NAME}_${BUILD_NUMBER}/arch/arm/configs/
+#cd ${JENKINS_HOME}/jobs/pipeline/BUILD_${JOB_NAME}_${BUILD_NUMBER}/arch/arm64/configs/
 
-pushd arch/arm/configs
+pushd arch/arm64/configs
 
 # Checking the config of ipv6 and PRIO_SCHED modules in bcm2709_defconfig
 
-if grep -i CONFIG_IPV6=y "bcm2709_defconfig"; then
+if grep -i CONFIG_IPV6=y "bcmrpi3_defconfig"; then
     echo "Congiguration IPV6 is already set "
 else
-    if grep -i CONFIG_IPV6=m "bcm2709_defconfig"; then
-        sed -i -- 's/CONFIG_IPV6=m/CONFIG_IPV6=y/g' bcm2709_defconfig
-        echo "Configuration IPV6 changed in bcm2709_defconfig"
+    if grep -i CONFIG_IPV6=m "bcmrpi3_defconfig"; then
+        sed -i -- 's/CONFIG_IPV6=m/CONFIG_IPV6=y/g' bcmrpi3_defconfig
+        echo "Configuration IPV6 changed in bcmrpi3_defconfig"
     else
-        echo "CONFIG_IPV6=y" >> bcm2709_defconfig
-        echo "Configuration IPV6 added in bcm2709_defconfig"
+        echo "CONFIG_IPV6=y" >> bcmrpi3_defconfig
+        echo "Configuration IPV6 added in bcmrpi3_defconfig"
     fi
 fi
 
-if grep -i CONFIG_RT_PRIO_SCHED=y "bcm2709_defconfig"; then
+if grep -i CONFIG_RT_PRIO_SCHED=y "bcmrpi3_defconfig"; then
     echo "Congiguration RT_PRIO_SCHED is already set"
 else
-    if grep -i CONFIG_RT_PRIO_SCHED=m "bcm2709_defconfig"; then
-        sed -i -- 's/CONFIG_RT_PRIO_SCHED=m/CONFIG_RT_PRIO_SCHED=y/g' bcm2709_defconfig
-        echo "Configuration RT_PRIO_SCHED changed in bcm2709_defconfig"
+    if grep -i CONFIG_RT_PRIO_SCHED=m "bcmrpi3_defconfig"; then
+        sed -i -- 's/CONFIG_RT_PRIO_SCHED=m/CONFIG_RT_PRIO_SCHED=y/g' bcmrpi3_defconfig
+        echo "Configuration RT_PRIO_SCHED changed in bcmrpi3_defconfig"
     else
-        echo "CONFIG_RT_PRIO_SCHED=y" >> bcm2709_defconfig
-        echo "Configuration RT_PRIO_SCHED added in bcm2709_defconfig"
+        echo "CONFIG_RT_PRIO_SCHED=y" >> bcmrpi3_defconfig
+        echo "Configuration RT_PRIO_SCHED added in bcmrpi3_defconfig"
     fi
 fi
 popd
 
 # create the .config, at the root of the source tree
-make ARCH=arm CROSS_COMPILE=arm-linux-gnueabihf- bcm2709_defconfig
+make ARCH=arm64 CROSS_COMPILE=aarch64-linux-gnu- bcmrpi3_defconfig
 
 # add extra information to the kernel version
 # short commmit id, and build number
 GIT_AND_BUILD_VER="$(git rev-parse --short HEAD)-${BUILD_NUMBER}"
 
 # Append CONFIG_LOCALVERSION with Build_Number in .config file
-if grep -i 'CONFIG_LOCALVERSION="-v7"' ".config"; then
-    sed -i -- 's/CONFIG_LOCALVERSION="-v7"/CONFIG_LOCALVERSION="'-v7-${GIT_AND_BUILD_VER}'"/g' .config
+if grep -i 'CONFIG_LOCALVERSION="-v8"' ".config"; then
+    sed -i -- 's/CONFIG_LOCALVERSION="-v8"/CONFIG_LOCALVERSION="'-v8-${GIT_AND_BUILD_VER}'"/g' .config
     echo "configuration LOCALVERSION changed in .config file to append ${GIT_AND_BUILD_VER}"
 else
-    echo "config LOCALVERSION=-v7 not found - failed"
+    echo "config LOCALVERSION=-v8 not found - failed"
 fi
 
-make -j4 ARCH=arm CROSS_COMPILE=arm-linux-gnueabihf- zImage modules dtbs
+make -j4 ARCH=arm64 CROSS_COMPILE=aarch64-linux-gnu- Image modules dtbs
 
 # make modules.tgz file
 rm -rf modules.tgz || true
 rm -rf modules-staging || true
 mkdir -p modules-staging
 
-make ARCH=arm CROSS_COMPILE=arm-linux-gnueabihf- INSTALL_MOD_PATH=modules-staging modules_install
+make ARCH=arm64 CROSS_COMPILE=aarch64-linux-gnu- INSTALL_MOD_PATH=modules-staging modules_install
 pushd modules-staging
 tar -czf modules.tgz *
 popd

^ permalink raw reply related	[flat|nested] only message in thread

only message in thread, other threads:[~2021-03-17 11:50 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -1,60 +1,60 @@
 
-# Checking the config of ipv6 and PRIO_SCHED modules in bcm2709_defconfig
+# Checking the config of ipv6 and PRIO_SCHED modules in bcmrpi3_defconfig
 
2021-03-17 11:50 [Fuego] Functional.raspi_kinstall Pavan Arun Deshpande

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.